@@ -192,8 +192,9 @@ class SubprocessManager(object):
             return True
 
     def run(self, runner):
-        self._add_runner(runner)
+        rid = self._add_runner(runner)
         runner.run()
+        return rid
 
     def _add_runner(self, runner):
         rid = str(uuid.uuid4())
@@ -206,3 +207,4 @@ class SubprocessManager(object):
             raise Exception('Could not create a new runner...')
 
         self._runners[rid] = runner
+        return rid
